#
# spec file for package gotestsum
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gotestsum
Version:        1.12.3
Release:        1.1
Summary:        CLI Go test runner with output optimized for human readability
License:        Apache-2.0
Group:          Development/Languages/Go
URL:            https://github.com/gotestyourself/gotestsum
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.21

%description
Go test runner with output optimized for humans, JUnit XML for CI integration,
and a summary of the test results.

%prep
%autosetup -a 1

%build
%ifnarch ppc64
export GOFLAGS="-buildmode=pie"
go build
%endif

%check
# execute the binary as a basic check
./%{name} --help

%install
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE NOTICE
%{_bindir}/%{name}

%changelog
* Sat Jul  5 2025 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.12.3:
  * Bump deps
  * --rerun-fails-abort-on-data-race
  * Use earlier and latest event time for elapsed time
  * go junitxml: compute per package start times rather than using per execution
  * feat: support for hidding skipped tests in the junit report
* Sat Mar 22 2025 Jeff Kowalczyk <jkowalczyk@suse.com>
- Packaging improvements:
  * Update to BuildRequires: golang(API) >= 1.21 matching go.mod
  * Build PIE with pattern that may become recommended procedure:
    %%%%ifnarch ppc64 GOFLAGS="-buildmode=pie" %%%%endif go build
    A go toolchain buildmode default config would be preferable
    but none exist at this time.
  * Drop mod=vendor, go1.14+ will detect vendor dir and auto-enable
* Sat Mar 22 2025 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.12.1:
  * Update expected values
  * fix swallow build error and added tests
  * Update TestEvent for go1.24
  * Bump golang.org/x/term from 0.24.0 to 0.29.0
  * Remove unused nolint directives
  * Bump golang.org/x/sys from 0.25.0 to 0.28.0
  * Fix some typos in README
  * Bump github.com/fsnotify/fsnotify from 1.7.0 to 1.8.0
  * fixup! fix(validate): fixes check for test.failfast flag as this is a gotest arg and must be prefixed with test.
  * fix(validate): fixes check for test.failfast flag as this is a gotest arg and must be prefixed with test.
  * Update x/text
  * Update x/tools
  * Update x/mod
  * Skip a test that flakes in CI
  * Fix lint
  * Update minimum Go version
  * fix ordering for version at least
  * Try updated golangci-lint
  * Remove old Go versions from CI
  * Bump golang.org/x/term from 0.20.0 to 0.24.0
  * Skip test that is falky on macos
  * Bump golang.org/x/sys from 0.20.0 to 0.24.0
  * Updated expected value for help text
  * Remove unnecessary empty lines
  * Fix typo in help text
  * Fix help text typo
  * omit empty skipped
  * add skipped attribute to junit xml testsuite
  * Bump golang.org/x/term from 0.18.0 to 0.20.0
  * Bump golang.org/x/sys from 0.18.0 to 0.20.0
  * Bump github.com/fatih/color from 1.16.0 to 1.17.0
  * fix: close FailsReportFile
  * Bump golang.org/x/sync from 0.6.0 to 0.7.0
* Sat Mar 22 2025 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.12.0:
  * ci: windows git config
  * Version check that is go1.21 compatible
  * go1.22~ added package build errors to the test output
  * Update ci config
  * Bump dependencies, update github workflows, add dependabot
  * Add gofiber/fiber to list of projects
  * Fix append bug in --rerun-fails with -run flag
  * Add Woodpecker CI to no-color default autodetection
  * Fold for loop clauses into the statement
  * Update README.md
  * Update gotestsum retries to properly filter out parents when there is a missing gap in the parent tree
  * Used named constants instead of magic numbers in illumos-specific code
  * Improve warning message when stdin is not a terminal
  * Add support for gotestsum on illumos/amd64
  * Update help text for font icons
  * filewatcher: Silence warning from os.Stat failures
  * Add emoticons to the nerdfonts icon formats
  * Add format icons for nerdfonts instead of unicode
  * Add support for simple icons using plain text
  * Add environment variable for setting format icons
  * Refactor color support for icons and add comments
  * Prepare for adding more icon options
* Sat Aug 12 2023 jkowalczyk@suse.com
- Update to version 1.10.1:
  * Add test for accepting GODEBUG output
  * Quote test names before they are used within the regex to rerun
  * move TEAMCITY_VERSION version checkout outside of CI check
  * Don't treat debug messages as errors
  * Add support for zOS
  * update fixture
  * fix lint
  * extract TEAMCITY_VERSION check because they don't set CI
  * Detect CI environments by name
  * Revert "Enable color support by default on Drone CI"
  * Enable color support by default on Drone CI
  * Update README.md
  * Fix coverage detection for go1.20
  * ci: update goreleaser 1.7.0 to 1.17.0 for windows/arm64
  * Add prometheus to readme links
  * Add list of projects that use gotestsum
* Thu Jun  8 2023 jkowalczyk@suse.com
- Initial package version 1.10.0:
  * slowest: Add topN flag
  * Convert testname formatter to new interface
  * Convert pkgname formats
  * Convert two more formatters to new interface
  * Convert two formatters to new interface
  * Avoid appending bytes
  * Add jsonfile-timing-events flag for capturing only the terminal events
  * Ensure jsonfile is flushed before running post-run-command
  * Hide standard-json format for now
  * Add standard-json format
  * ci-matrix: improve description
  * Update expected value for new output of subtests
  * Update golangci-lint
  * Use go 1.20 in CI
  * Expect test to run for rename
  * Fix need to save twice to trigger watch
